@@ -19,47 +19,49 @@ class Pumps:
 
     def pump_peace(self, tube, volume):
         self.pe.Valves.close_all_valves()  # redundant valve close for safety
-        self.log_pump_operation(pump1Volume=volume, comment="started pumping")
+        self.log_pump_operation(tube=tube, pump1Volume=volume, comment="started pumping")
         self.pe.Valves.open_valve(tube)
         time.sleep(0.5)
         steps = int(volume * self.pump_coefficients[1])
         self.dev.request(pm.dev_msg.PumpRequest(pump1Volume=steps))
-        time.sleep(0.5)  # release all pressure in the tubes
+        time.sleep(0.5)  # release all pressure in the tubes before closing the valve
         self.pe.Valves.close_valve(tube)
-        self.log_pump_operation(pump1Volume=volume, comment="completed pumping")
+        self.log_pump_operation(tube=tube, pump1Volume=volume, comment="completed pumping")
 
     def pump_death(self, tube, volume):
         self.pe.Valves.close_all_valves()  # redundant valve close for safety
-        self.log_pump_operation(pump2Volume=volume, comment="started pumping")
+        self.log_pump_operation(tube=tube, pump2Volume=volume, comment="started pumping")
         self.pe.Valves.open_valve(tube)
         time.sleep(0.5)
         steps = int(volume * self.pump_coefficients[2])
         self.dev.request(pm.dev_msg.PumpRequest(pump2Volume=steps))
-        time.sleep(0.5)  # release all pressure in the tubes
+        time.sleep(0.5)  # release all pressure in the tubes before closing the valve
         self.pe.Valves.close_valve(tube)
-        self.log_pump_operation(pump2Volume=volume, comment="completed pumping")
+        self.log_pump_operation(tube=tube, pump2Volume=volume, comment="completed pumping")
 
     def pump_vacuum(self, tube, volume):
         self.pe.Valves.close_all_valves()  # redundant valve close for safety
-        self.log_pump_operation(pump3Volume=volume, comment="started pumping")
+        self.log_pump_operation(tube=tube, pump3Volume=volume, comment="started pumping")
         self.pe.Valves.open_valve(tube)
         time.sleep(0.5)
         steps = int(volume * self.pump_coefficients[3])
         self.dev.request(pm.dev_msg.PumpRequest(pump3Volume=steps))
-        time.sleep(0.5)  # release all pressure in the tubes
+        time.sleep(0.5)  # release all pressure in the tubes before closing the valve
         self.pe.Valves.close_valve(tube)
-        self.log_pump_operation(pump3Volume=volume, comment="completed pumping")
+        self.log_pump_operation(tube=tube, pump3Volume=volume, comment="completed pumping")
 
-    def log_pump_operation(self, pump1Volume=0, pump2Volume=0, pump3Volume=0, comment=""):
+    def log_pump_operation(self, tube, pump1Volume=0, pump2Volume=0, pump3Volume=0,comment=""):
         if not os.path.exists(self.logfile):
             with open(self.logfile, "w+") as f:
-                f.write("Time, pump1Volume, pump2Volume, pump3Volume, comment\n")
-        pump1Volume = str(pump1Volume)
-        pump2Volume = str(pump2Volume)
-        pump3Volume = str(pump3Volume)
-        log_string = ", ".join([time.ctime(), pump1Volume, pump2Volume, pump3Volume, comment]) + "\n"
+                f.write("Time, tube, pump1Volume, pump2Volume, pump3Volume, comment\n")
+
         with open(self.logfile, "a") as f:
-            f.write(log_string)
+            f.write("{time}, {tube:1d}, {v1:.3f}, {v2:.3f}, {v3:.3f}, {comment}\n".format(time=current_time,
+                                                                                tube=tube,
+                                                                                v1=pump1Volume,
+                                                                                v2=pump2Volume,
+                                                                                v3=pump3Volume,
+                                                                                comment=comment))
 
     def calibrate(self, tube=None, requested_volume=None, real_volume=None):
         """
@@ -74,7 +76,7 @@ class Pumps:
         pump = int(input(pump_input_string))
         if tube is None:
             tube = int(input("Please select which tube to pump into: \n (0,1,2,3,4,5 or 6)"))
-            assert tube in [0,1,2,3,4,5,6]
+            assert tube in [0, 1, 2, 3, 4, 5, 6]
 
         if requested_volume is None:
             requested_volume = float(input("Please input volume to pump in ml: \n(max 20)"))
